<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 01/28/2004 *
 * ===================                          Last change: 12/13/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-list_links.php                              *
 * -------------------------------------------------------------------- *
 * Short description : List unconfirmed mails of a member               *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Unbest&auml;tigte Mails eines Mitgliedes auflisten   *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!isAdmin())) {
	die();
} // END - if

// Add description as navigation point
addYouAreHereLink('admin', __FILE__);

if (!isExtensionActive('mailid')) {
	displayMessage('{%pipe,generateExtensionInactiveNotInstalledMessage=mailid%}');
	return;
} // END - if

if (isGetRequestElementSet('userid')) {
	// Check if the user already exists
	if (fetchUserData(getRequestElement('userid'))) {
		// Default is ext-bonus is not installed
		$rowName = 'stats_id';

		// Is ext-bonus installed?
		if (isExtensionActive('bonus')) {
			// Use bonus_id
			$linkDataName = 'bonus_id';
		} // END - if

		// Load user links data
		$result = SQL_QUERY_ESC("SELECT `userid`, `stats_id`, `%s`, `link_type` FROM `{?_MYSQL_PREFIX?}_user_links` WHERE `userid`=%s ORDER BY `id` ASC",
			array(
				$linkDataName,
				bigintval(getRequestElement('userid'))
			), __FILE__, __LINE__);

		// Are there some entries?
		if (!SQL_HASZERONUMS($result)) {
			// Some unconfirmed mails left
			if (getRequestElement('delete') == 'all') {
				// Delete all unconfirmed mails by this user
				SQL_QUERY_ESC("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_user_links` WHERE `userid`=%s LIMIT %s",
					array(bigintval(getRequestElement('userid')), SQL_NUMROWS($result)), __FILE__, __LINE__);

				// Prepare mail and send it away
				$message = loadEmailTemplate('member_delete_links', SQL_NUMROWS($result), bigintval(getRequestElement('userid')));
				sendEmail(getUserData('userid'), '{--ADMIN_DELETE_LINK_SUBJECT--}', $message);

				// Display message
				displayMessage('{--ADMIN_LINKS_DELETED--}');
			} else {
				// Init variables
				$OUT = '';

				// List all unconfirmed mails
				while ($linkData = SQL_FETCHARRAY($result)) {
					// Initializes all other elements
					$linkData['mail_id'] = '';
					$linkData['problem'] = '{--ADMIN_GENERAL_MAIL_PROBLEM--}';
					$result_data = false;

					// Load data from stats table...
					// @TODO Rewrite this to includes/filter
					switch ($linkData['link_type']) {
						case 'NORMAL':
							$result_data = SQL_QUERY_ESC("SELECT `subject`, `timestamp_ordered` AS `timestamp`, `cat_id` FROM `{?_MYSQL_PREFIX?}_user_stats` WHERE `id`=%s LIMIT 1",
								array(bigintval($linkData['stats_id'])), __FILE__, __LINE__);
							$linkData['link_type'] = 'mailid';
							$linkData['mail_id']   = $linkData['stats_id'];
							$linkData['problem']   = '{--NORMAL_MAIL_PROBLEM--}';
							break;

						case 'BONUS':
							$result_data = SQL_QUERY_ESC("SELECT `subject`, `timestamp`, `cat_id` FROM `{?_MYSQL_PREFIX?}_bonus` WHERE `id`=%s LIMIT 1",
								array(bigintval($linkData['bonus_id'])), __FILE__, __LINE__);
							$linkData['link_type'] = 'bonusid';
							$linkData['mail_id']   = $linkData['bonus_id'];
							$linkData['problem']   = '{--BONUS_MAIL_PROBLEM--}';
							break;

						default: // Problem in application detected!
							reportBug(__FILE__, __LINE__, sprintf("Invalid email type %s detected.", $linkData['link_type']));
							break;
					} // END - switch

					// Is there an entry?
					if (SQL_NUMROWS($result_data) == 1) {
						// Mail was found
						$mailData = merge_array($linkData, SQL_FETCHARRAY($result_data));

						// Fix empty subject
						if (empty($mailData['subject'])) {
							// The subject line is empty so we use the default
							$mailData['subject'] = '{--DEFAULT_SUBJECT_LINE--}';
						} // END - if

						// Prepare data for the row template
						$mailData['timestamp'] = generateDateTime($mailData['timestamp'], 0);

						// Load row template
						$OUT .= loadTemplate('admin_list_links_row', true, $mailData);
					} else {
						// Load template for error
						$OUT .= loadTemplate('admin_list_links_problem', true, $linkData);
					}

					// Free result
					SQL_FREERESULT($result_data);
				} // END - while

				// Remember list in constant for the template
				$content = array(
					'email'   => '<a href="' . generateEmailLink(getUserData('email'), 'user_data') . '">' . getUserData('email') . '</a>',
					'rows'    => $OUT,
					'nums'    => SQL_NUMROWS($result),
					'userid'  => bigintval(getRequestElement('userid')),
				);

				// Free memory
				SQL_FREERESULT($result);

				// Load final template
				loadTemplate('admin_list_links', false, $content);
			}
		} else {
			// No mails left to confirm
			displayMessage('{%message,ADMIN_NO_UNCONFIRMED_MAILS_LEFT=' . bigintval(getRequestElement('userid')) . '%}');
		}
	} else {
		// User not found
		displayMessage('{%message,ADMIN_MEMBER_404=' . bigintval(getRequestElement('userid')) . '%}');
	}
} else {
	// Output selection form with all confirmed user accounts listed
	addMemberSelectionBox();
}

// [EOF]
?>
