<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 10/09/2012 *
 * ===================                          Last change: 10/09/2012 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-list_user_subid.php                         *
 * -------------------------------------------------------------------- *
 * Short description : List all URLs in user_subid                      *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Alle URLs in user_subid auflisten                *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!isAdmin())) {
	die();
} // END - if

// Add description as navigation point
addYouAreHereLink('admin', __FILE__);

// By default show the list...
$show = true;

// Check for 'id' element
if ((countRequestPost() > 0) && (!ifPostContainsSelections('id')) && (!ifPostContainsSelections('subid'))) {
	// Not found so output message
	displayMessage('{--ADMIN_USER_SUBID_NO_SELECTIONS--}');

	// Abort here
	return;
} // END - if

// Edit or delete button hit?
if (isFormSent('edit')) {
	// Show entries for editing
	showEntriesByXmlCallback('admin_edit_show_user_subid');

	// Do not show the list of URLs after this template
	$show = false;
} elseif (isFormSent('do_edit')) {
	// Change data of entries
	showEntriesByXmlCallback('admin_edit_do_user_subid');
} elseif (isFormSent('delete')) {
	// Show entries for deletion
	showEntriesByXmlCallback('admin_delete_show_user_subid');

	// Do not show the list of URLs after this template
	$show = false;
} elseif (isFormSent('do_delete')) {
	// Remove entries from database
	showEntriesByXmlCallback('admin_delete_do_user_subid');
} elseif (isFormSent('do_delete_stats')) {
	// Remove entries from database
	showEntriesByXmlCallback('admin_delete_do_user_subid_stats');
} elseif ((isGetRequestElementSet('do')) && (isGetRequestElementSet('id'))) {
	// Construct module name
	$incFile = sprintf("inc/modules/admin/subid-%s.php", SQL_ESCAPE(getRequestElement('do')));

	// Is the include readable and is the sub id assigned to current admin?
	if (!isUserSubIdAssignedToMember(getRequestElement('id'), getRequestElement('userid'))) {
		// Sub id is not assigned to current admin or doesn't exist
		reportBug(__FILE__, __LINE__, 'Sub id ' . getRequestElement('id') . ' is not assigned with userid ' .getRequestElement('userid'));
	} elseif (isIncludeReadable($incFile)) {
		// Then include it
		loadIncludeOnce($incFile);

		// Do not show the list of URLs after this template
		$show = false;
	} else {
		// Display error message
		reportBug(__FILE__, __LINE__, 'Invalid include file ' . basename($incFile) . ' detected.');
	}
}

// Show entries?
if ($show === false) {
	// No, a form has already been show
	return false;
} // END - if

// Is a user id sent?
if (isGetRequestElementSet('userid')) {
	// List all sub ids
	showEntriesByXmlCallback('admin_list_user_subid', array(
		'userid' => bigintval(getRequestElement('userid'))
	));
} else {
	// Output selection form with all confirmed user accounts listed
	addMemberSelectionBox();
}

// [EOF]
?>
